# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/refresh_token.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/refresh_token.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/iam/v1/refresh_token.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\x03\n\x0cRefreshToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x14\x63lient_instance_info\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x12\n\nsubject_id\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_used_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x10protection_level\x18\x08 \x01(\x0e\x32\x31.yandex.cloud.iam.v1.RefreshToken.ProtectionLevel\"r\n\x0fProtectionLevel\x12 \n\x1cPROTECTION_LEVEL_UNSPECIFIED\x10\x00\x12\x11\n\rNO_PROTECTION\x10\x01\x12\x15\n\x11INSECURE_KEY_DPOP\x10\x02\x12\x13\n\x0fSECURE_KEY_DPOP\x10\x03\x42V\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.refresh_token_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_REFRESHTOKEN']._serialized_start=98
  _globals['_REFRESHTOKEN']._serialized_end=532
  _globals['_REFRESHTOKEN_PROTECTIONLEVEL']._serialized_start=418
  _globals['_REFRESHTOKEN_PROTECTIONLEVEL']._serialized_end=532
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import video_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2
from yandex.cloud.video.v1 import video_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/video/v1/video_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class VideoServiceStub(object):
    """Video management service.
    Provides methods for creating, retrieving, updating, and deleting videos,
    as well as managing video-related operations such as transcoding, publishing,
    and generating playback URLs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/Get',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2.Video.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoResponse.FromString,
                _registered_method=True)
        self.BatchGet = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/BatchGet',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.CreateVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/Update',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.UpdateVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Transcode = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/Transcode',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.TranscodeVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/Delete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.DeleteVideoRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.BatchDelete = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/BatchDelete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchDeleteVideosRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.PerformAction = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/PerformAction',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.PerformVideoActionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetPlayerURL = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/GetPlayerURL',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLResponse.FromString,
                _registered_method=True)
        self.BatchGetPlayerURLs = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/BatchGetPlayerURLs',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsResponse.FromString,
                _registered_method=True)
        self.GetManifests = channel.unary_unary(
                '/yandex.cloud.video.v1.VideoService/GetManifests',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsResponse.FromString,
                _registered_method=True)


class VideoServiceServicer(object):
    """Video management service.
    Provides methods for creating, retrieving, updating, and deleting videos,
    as well as managing video-related operations such as transcoding, publishing,
    and generating playback URLs.
    """

    def Get(self, request, context):
        """Retrieves detailed information about a specific video by its ID.
        Returns all video metadata, status, and related information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all videos in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGet(self, request, context):
        """Retrieves multiple videos by their IDs in a specific channel in a single request.
        This is more efficient than making multiple Get requests when retrieving several videos.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new video in the specified channel.
        The video can be created from different sources: TUS upload, direct link, or S3 storage.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing video's metadata and settings.
        Only fields specified in the field_mask will be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Transcode(self, request, context):
        """Initiates or updates video transcoding with specified parameters.
        Can be used to start transcoding for videos with auto_transcode=DISABLE,
        or to re-process a completed video with new transcoding settings.
        Supports additional features like subtitle processing, translation, and summarization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a specific video by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDelete(self, request, context):
        """Deletes multiple videos in a specific channel in a single request.
        This is more efficient than making multiple Delete requests when removing several videos.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformAction(self, request, context):
        """Performs a specific action on a video, such as publishing or unpublishing.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlayerURL(self, request, context):
        """Generates a standard player URL for watching the video.
        The URL respects the video's access rights and can include custom player parameters.
        For videos with signed URL access, an expiration duration can be specified.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetPlayerURLs(self, request, context):
        """Generates multiple player URLs for a list of videos in a specific channel in a single request.
        This is more efficient than making multiple GetPlayerURL requests when retrieving several URLs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManifests(self, request, context):
        """Retrieves the manifest URLs for a specific video.
        Manifests are used by video players to access the video content with adaptive bitrate streaming.
        Supports different manifest types (HLS, DASH) and configuration parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VideoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2.Video.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoResponse.SerializeToString,
            ),
            'BatchGet': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGet,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.CreateVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.UpdateVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Transcode': grpc.unary_unary_rpc_method_handler(
                    servicer.Transcode,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.TranscodeVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.DeleteVideoRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDelete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchDeleteVideosRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'PerformAction': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformAction,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.PerformVideoActionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetPlayerURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlayerURL,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLResponse.SerializeToString,
            ),
            'BatchGetPlayerURLs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetPlayerURLs,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsResponse.SerializeToString,
            ),
            'GetManifests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetManifests,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.VideoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.video.v1.VideoService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VideoService(object):
    """Video management service.
    Provides methods for creating, retrieving, updating, and deleting videos,
    as well as managing video-related operations such as transcoding, publishing,
    and generating playback URLs.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/Get',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2.Video.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.ListVideoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/BatchGet',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideosResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.CreateVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/Update',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.UpdateVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Transcode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/Transcode',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.TranscodeVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/Delete',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.DeleteVideoRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/BatchDelete',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchDeleteVideosRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PerformAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/PerformAction',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.PerformVideoActionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlayerURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/GetPlayerURL',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoPlayerURLResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGetPlayerURLs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/BatchGetPlayerURLs',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.BatchGetVideoPlayerURLsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetManifests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.VideoService/GetManifests',
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_video__service__pb2.GetVideoManifestsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.sku_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSkuRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the SKU to return.
    To get the SKU ID, use [SkuService.List] request.
    """
    currency: builtins.str
    """Currency of the SKU.
    Can be one of the following:
    * `RUB`
    * `USD`
    * `KZT`
    """
    billing_account_id: builtins.str
    """Optional ID of the billing account.
    If specified, contract prices for a particular billing account are included in the response.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        currency: builtins.str = ...,
        billing_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "currency", b"currency", "id", b"id"]) -> None: ...

global___GetSkuRequest = GetSkuRequest

@typing.final
class ListSkusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    currency: builtins.str
    """Currency of the prices.
    Can be one of the following:
    * `RUB`
    * `USD`
    * `KZT`
    """
    billing_account_id: builtins.str
    """Optional ID of the billing account.
    If specified, contract prices for a particular billing account are included in the response.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [yandex.cloud.billing.v1.Sku.id] and [yandex.cloud.billing.v1.Sku.service_id] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    E.g. `filter=serviceId="dn28hpu6268356q0j8mk"`.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListSkusResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListSkusResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        currency: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        filter: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "currency", b"currency", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSkusRequest = ListSkusRequest

@typing.final
class ListSkusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SKUS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSkusRequest.page_size], use
    [next_page_token] as the value
    for the [ListSkusRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def skus(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.sku_pb2.Sku]:
        """List of skus."""

    def __init__(
        self,
        *,
        skus: collections.abc.Iterable[yandex.cloud.billing.v1.sku_pb2.Sku] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "skus", b"skus"]) -> None: ...

global___ListSkusResponse = ListSkusResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.greenplum.v1.user_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    """Users API"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.user_pb2.User]: ...
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.user_pb2.User] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class GetUserAtRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster."""
    revision: builtins.int
    """Cluster revision"""
    user_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        revision: builtins.int = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "revision", b"revision", "user_name", b"user_name"]) -> None: ...

global___GetUserAtRevisionRequest = GetUserAtRevisionRequest

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def user(self) -> yandex.cloud.mdb.greenplum.v1.user_pb2.User: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user: yandex.cloud.mdb.greenplum.v1.user_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user", b"user"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def user(self) -> yandex.cloud.mdb.greenplum.v1.user_pb2.User: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        user: yandex.cloud.mdb.greenplum.v1.user_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "update_mask", b"update_mask", "user", b"user"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Maintenance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Maintenance._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Maintenance._Status.ValueType  # 0
        """Not set."""
        SCHEDULED: Maintenance._Status.ValueType  # 1
        """Maintenance is scheduled for a future time."""
        RUNNING: Maintenance._Status.ValueType  # 2
        """Maintenance is currently running."""
        SUCCEEDED: Maintenance._Status.ValueType  # 3
        """Maintenance completed successfully."""
        CANCELLED: Maintenance._Status.ValueType  # 4
        """Maintenance is cancelled and will not run."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Maintenance.Status.ValueType  # 0
    """Not set."""
    SCHEDULED: Maintenance.Status.ValueType  # 1
    """Maintenance is scheduled for a future time."""
    RUNNING: Maintenance.Status.ValueType  # 2
    """Maintenance is currently running."""
    SUCCEEDED: Maintenance.Status.ValueType  # 3
    """Maintenance completed successfully."""
    CANCELLED: Maintenance.Status.ValueType  # 4
    """Maintenance is cancelled and will not run."""

    @typing.final
    class Resource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """ID of the resource"""
        type: builtins.str
        """The type of the resource, e.g. resource-manager.cloud, resource-manager.folder, compute.instance, etc."""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    @typing.final
    class Detail(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Unique key (service-specific)."""
        value: builtins.str
        """Description (service-specific)."""
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    RESOURCE_PATH_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    START_SCHEDULED_AT_FIELD_NUMBER: builtins.int
    COMPLETION_SCHEDULED_AT_FIELD_NUMBER: builtins.int
    MAX_START_SCHEDULED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    SUCCEEDED_AT_FIELD_NUMBER: builtins.int
    CANCELLED_AT_FIELD_NUMBER: builtins.int
    USER_CONTROLLABLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the maintenance."""
    description: builtins.str
    """Describes action to be performed."""
    status: global___Maintenance.Status.ValueType
    """Status of the maintenance."""
    user_controllable: builtins.bool
    """Indicates whether the user can control (reschedule) the maintenance."""
    @property
    def resource_path(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Maintenance.Resource]:
        """Full path to the resource affected by maintenance,
        represented as a hierarchy from specific resource to top-level container.
        Example for a Compute instance with ID "I" in folder "F" and cloud "C":
        resource_path = [
           { "compute.instance", "I" },
           { "resource-manager.folder", "F" },
           { "resource-manager.cloud", "C" }
        ]
        """

    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Maintenance.Detail]:
        """Service-specific details."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The creation time of the maintenance."""

    @property
    def start_scheduled_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the maintenance was scheduled to start."""

    @property
    def completion_scheduled_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the maintenance is estimated to complete. Optional."""

    @property
    def max_start_scheduled_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Latest time the maintenance can be postponed to."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time time when the maintenance has actually started."""

    @property
    def succeeded_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time time when the maintenance has actually completed successfully."""

    @property
    def cancelled_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time time when the maintenance has actually been cancelled."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        resource_path: collections.abc.Iterable[global___Maintenance.Resource] | None = ...,
        description: builtins.str = ...,
        details: collections.abc.Iterable[global___Maintenance.Detail] | None = ...,
        status: global___Maintenance.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        start_scheduled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completion_scheduled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        max_start_scheduled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        succeeded_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cancelled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        user_controllable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cancelled_at", b"cancelled_at", "completion_scheduled_at", b"completion_scheduled_at", "created_at", b"created_at", "max_start_scheduled_at", b"max_start_scheduled_at", "start_scheduled_at", b"start_scheduled_at", "started_at", b"started_at", "succeeded_at", b"succeeded_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cancelled_at", b"cancelled_at", "completion_scheduled_at", b"completion_scheduled_at", "created_at", b"created_at", "description", b"description", "details", b"details", "id", b"id", "max_start_scheduled_at", b"max_start_scheduled_at", "resource_path", b"resource_path", "start_scheduled_at", b"start_scheduled_at", "started_at", b"started_at", "status", b"status", "succeeded_at", b"succeeded_at", "user_controllable", b"user_controllable"]) -> None: ...

global___Maintenance = Maintenance

@typing.final
class ListMaintenancesRequest(google.protobuf.message.Message):
    """ListMaintenancesRequest allows listing maintenances by cloud ID, folder ID, resource type or resource ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cloud_id: builtins.str
    """Cloud ID for the resources."""
    folder_id: builtins.str
    """Folder ID for the resources."""
    resource_id: builtins.str
    """Resource ID of the target resource."""
    page_size: builtins.int
    """The maximum number of maintenances to return per response."""
    page_token: builtins.str
    """Token to retrieve the next page of results. Omitted on the first request."""
    order_by: builtins.str
    """By which field the listing should be ordered and in which direction,
    format is "created_at desc". The default sorting order is ascending.
    Supported fields: ["created_at", "start_scheduled_at", "started_at"].
    """
    filter: builtins.str
    """Filter list by various fields.
    Supported fields: ["status", "resource_type", "resource_id"]
    """
    def __init__(
        self,
        *,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        resource_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "container", b"container", "folder_id", b"folder_id", "resource_id", b"resource_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "container", b"container", "filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "resource_id", b"resource_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["cloud_id", "folder_id", "resource_id"] | None: ...

global___ListMaintenancesRequest = ListMaintenancesRequest

@typing.final
class ListMaintenancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAINTENANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def maintenances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Maintenance]:
        """List of maintenances."""

    def __init__(
        self,
        *,
        maintenances: collections.abc.Iterable[global___Maintenance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["maintenances", b"maintenances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListMaintenancesResponse = ListMaintenancesResponse

@typing.final
class GetMaintenanceRequest(google.protobuf.message.Message):
    """GetMaintenanceRequest allows getting Maintenance by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAINTENANCE_ID_FIELD_NUMBER: builtins.int
    maintenance_id: builtins.str
    def __init__(
        self,
        *,
        maintenance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["maintenance_id", b"maintenance_id"]) -> None: ...

global___GetMaintenanceRequest = GetMaintenanceRequest

@typing.final
class RescheduleMaintenanceRequest(google.protobuf.message.Message):
    """RescheduleMaintenanceRequest allows to reschedule maintenance to another date and time."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RescheduleMaintenanceRequest._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: RescheduleMaintenanceRequest._Type.ValueType  # 0
        """Not set."""
        IMMEDIATE: RescheduleMaintenanceRequest._Type.ValueType  # 1
        """If the user wants to reschedule the maintenance to happen now."""
        NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest._Type.ValueType  # 2
        """If the user wants to reschedule the maintenance for the next maintenance window."""
        SPECIFIC_TIME: RescheduleMaintenanceRequest._Type.ValueType  # 3
        """If the user wants to reschedule the maintenance to a specific time."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: RescheduleMaintenanceRequest.Type.ValueType  # 0
    """Not set."""
    IMMEDIATE: RescheduleMaintenanceRequest.Type.ValueType  # 1
    """If the user wants to reschedule the maintenance to happen now."""
    NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest.Type.ValueType  # 2
    """If the user wants to reschedule the maintenance for the next maintenance window."""
    SPECIFIC_TIME: RescheduleMaintenanceRequest.Type.ValueType  # 3
    """If the user wants to reschedule the maintenance to a specific time."""

    MAINTENANCE_ID_FIELD_NUMBER: builtins.int
    RESCHEDULE_TYPE_FIELD_NUMBER: builtins.int
    SCHEDULED_AT_FIELD_NUMBER: builtins.int
    maintenance_id: builtins.str
    """Required. ID of the maintenance."""
    reschedule_type: global___RescheduleMaintenanceRequest.Type.ValueType
    """Required. If `reschedule_type` is "SPECIFIC_TIME",
    must set up `schedule_time` as well.
    """
    @property
    def scheduled_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Optional. Timestamp the maintenance shall be rescheduled to,
        if `reschedule_type` = "SPECIFIC_TIME".
        Must be in RFC 3339 format (e.g. "2025-11-15T16:19:00.094Z").
        """

    def __init__(
        self,
        *,
        maintenance_id: builtins.str = ...,
        reschedule_type: global___RescheduleMaintenanceRequest.Type.ValueType = ...,
        scheduled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scheduled_at", b"scheduled_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["maintenance_id", b"maintenance_id", "reschedule_type", b"reschedule_type", "scheduled_at", b"scheduled_at"]) -> None: ...

global___RescheduleMaintenanceRequest = RescheduleMaintenanceRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OpenSearchConfig2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CLAUSE_COUNT_FIELD_NUMBER: builtins.int
    FIELDDATA_CACHE_SIZE_FIELD_NUMBER: builtins.int
    REINDEX_REMOTE_WHITELIST_FIELD_NUMBER: builtins.int
    fielddata_cache_size: builtins.str
    """the percentage or absolute value (10%, 512mb) of heap space that is allocated to fielddata"""
    reindex_remote_whitelist: builtins.str
    @property
    def max_clause_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """the maximum number of allowed boolean clauses in a query"""

    def __init__(
        self,
        *,
        max_clause_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        fielddata_cache_size: builtins.str = ...,
        reindex_remote_whitelist: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_clause_count", b"max_clause_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fielddata_cache_size", b"fielddata_cache_size", "max_clause_count", b"max_clause_count", "reindex_remote_whitelist", b"reindex_remote_whitelist"]) -> None: ...

global___OpenSearchConfig2 = OpenSearchConfig2

@typing.final
class OpenSearchConfigSet2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___OpenSearchConfig2: ...
    @property
    def user_config(self) -> global___OpenSearchConfig2: ...
    @property
    def default_config(self) -> global___OpenSearchConfig2: ...
    def __init__(
        self,
        *,
        effective_config: global___OpenSearchConfig2 | None = ...,
        user_config: global___OpenSearchConfig2 | None = ...,
        default_config: global___OpenSearchConfig2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___OpenSearchConfigSet2 = OpenSearchConfigSet2



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SessionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    BACKEND_START_FIELD_NUMBER: builtins.int
    XACT_START_FIELD_NUMBER: builtins.int
    QUERY_START_FIELD_NUMBER: builtins.int
    STATE_CHANGE_FIELD_NUMBER: builtins.int
    WAIT_EVENT_TYPE_FIELD_NUMBER: builtins.int
    WAIT_EVENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    BACKEND_TYPE_FIELD_NUMBER: builtins.int
    CLIENT_ADDR_FIELD_NUMBER: builtins.int
    CLIENT_HOSTNAME_FIELD_NUMBER: builtins.int
    CLIENT_PORT_FIELD_NUMBER: builtins.int
    BACKEND_XID_FIELD_NUMBER: builtins.int
    BACKEND_XMIN_FIELD_NUMBER: builtins.int
    BLOCKING_PIDS_FIELD_NUMBER: builtins.int
    QUERY_ID_FIELD_NUMBER: builtins.int
    host: builtins.str
    """Host of the connected client."""
    pid: builtins.int
    """Server process ID. For client connections, this is a client connection ID."""
    database: builtins.str
    """Database ID."""
    user: builtins.str
    """User ID."""
    application_name: builtins.str
    """Application name on the connected client."""
    wait_event_type: builtins.str
    """Type of event for which the backend is waiting. Such an event is called a wait event. A backend refers to the process that maintains the client connection.

    For the list of wait events, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/monitoring-stats.html#WAIT-EVENT-TABLE). If the backend is not waiting for any event, the parameter returns [NULL].
    """
    wait_event: builtins.str
    """Wait event name.

    For the list of such names, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/monitoring-stats.html#WAIT-EVENT-ACTIVITY-TABLE). If the backend is not waiting for any event, the parameter returns [NULL].
    """
    state: builtins.str
    """Current backend state. For the list of possible values, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW)."""
    query: builtins.str
    """Text of the most recent query.

    If the [state] parameter takes the value [active], the parameter shows the currently executing query. For the rest of the states, the parameter shows the last query that was executed. By default, the query text is truncated to 1024 bytes.
    """
    backend_type: builtins.str
    """Current backend type. For the list of possible values, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW)."""
    client_addr: builtins.str
    """IP address of the connected client.

    The parameter returns [NULL] in the following cases:
    - The client is connected via a Unix socket on the server.
    - A given process is internal (for example, autovacuum).
    """
    client_hostname: builtins.str
    """Host name of the connected client (relevant for IP connections)."""
    client_port: builtins.int
    """TCP port number that the client is using for communication with the server.

    Returns [-1] if the client is connected via a Unix socket on the server. Returns [NULL] if a given process is internal (for example, autovacuum).
    """
    backend_xid: builtins.int
    """Top-level transaction ID, if any."""
    backend_xmin: builtins.int
    """Current [xmin horizon]."""
    blocking_pids: builtins.str
    """Process IDs that are blocking a given server process ID."""
    query_id: builtins.str
    """Query ID."""
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of collecting statistics on sessions (in the [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format)."""

    @property
    def backend_start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when a given process was started. For client connections, this is the time when the client connected to the server."""

    @property
    def xact_start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when a transaction of a given process was started. Returns [NULL] if no transaction is active.

        If the currently active query is the first of its transaction, the value of this parameter is equal to the value of the [query_start] parameter.
        """

    @property
    def query_start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the currently active query was started.

        If the [state] parameter does not take the value [active], the parameter returns the time when the lastest query was started.
        """

    @property
    def state_change(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the [state] parameter was last changed."""

    def __init__(
        self,
        *,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        host: builtins.str = ...,
        pid: builtins.int = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        application_name: builtins.str = ...,
        backend_start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        xact_start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        query_start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state_change: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        wait_event_type: builtins.str = ...,
        wait_event: builtins.str = ...,
        state: builtins.str = ...,
        query: builtins.str = ...,
        backend_type: builtins.str = ...,
        client_addr: builtins.str = ...,
        client_hostname: builtins.str = ...,
        client_port: builtins.int = ...,
        backend_xid: builtins.int = ...,
        backend_xmin: builtins.int = ...,
        blocking_pids: builtins.str = ...,
        query_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend_start", b"backend_start", "query_start", b"query_start", "state_change", b"state_change", "time", b"time", "xact_start", b"xact_start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_name", b"application_name", "backend_start", b"backend_start", "backend_type", b"backend_type", "backend_xid", b"backend_xid", "backend_xmin", b"backend_xmin", "blocking_pids", b"blocking_pids", "client_addr", b"client_addr", "client_hostname", b"client_hostname", "client_port", b"client_port", "database", b"database", "host", b"host", "pid", b"pid", "query", b"query", "query_id", b"query_id", "query_start", b"query_start", "state", b"state", "state_change", b"state_change", "time", b"time", "user", b"user", "wait_event", b"wait_event", "wait_event_type", b"wait_event_type", "xact_start", b"xact_start"]) -> None: ...

global___SessionState = SessionState

@typing.final
class PrimaryKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    TOPLEVEL_FIELD_NUMBER: builtins.int
    QUERY_ID_FIELD_NUMBER: builtins.int
    PLAN_ID_FIELD_NUMBER: builtins.int
    host: builtins.str
    """Host of the connected client."""
    user: builtins.str
    """User ID."""
    database: builtins.str
    """Database ID."""
    toplevel: builtins.bool
    """Returns [true] if a query is executed as a top-level SQL statement or if the [pg_stat_statements.track](https://www.postgresql.org/docs/current/pgstatstatements.html#id-1.11.7.41.9) parameter is set to the value [top]."""
    query_id: builtins.str
    """Query ID."""
    plan_id: builtins.str
    """Query planning ID."""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        user: builtins.str = ...,
        database: builtins.str = ...,
        toplevel: builtins.bool = ...,
        query_id: builtins.str = ...,
        plan_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "host", b"host", "plan_id", b"plan_id", "query_id", b"query_id", "toplevel", b"toplevel", "user", b"user"]) -> None: ...

global___PrimaryKey = PrimaryKey

@typing.final
class QueryStats(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    NORMALIZED_PLAN_FIELD_NUMBER: builtins.int
    EXAMPLE_PLAN_FIELD_NUMBER: builtins.int
    PLANS_FIELD_NUMBER: builtins.int
    TOTAL_PLAN_TIME_FIELD_NUMBER: builtins.int
    MIN_PLAN_TIME_FIELD_NUMBER: builtins.int
    MAX_PLAN_TIME_FIELD_NUMBER: builtins.int
    MEAN_PLAN_TIME_FIELD_NUMBER: builtins.int
    STDDEV_PLAN_TIME_FIELD_NUMBER: builtins.int
    CALLS_FIELD_NUMBER: builtins.int
    TOTAL_TIME_FIELD_NUMBER: builtins.int
    MIN_TIME_FIELD_NUMBER: builtins.int
    MAX_TIME_FIELD_NUMBER: builtins.int
    MEAN_TIME_FIELD_NUMBER: builtins.int
    STDDEV_TIME_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    SHARED_BLKS_HIT_FIELD_NUMBER: builtins.int
    SHARED_BLKS_READ_FIELD_NUMBER: builtins.int
    SHARED_BLKS_DIRTIED_FIELD_NUMBER: builtins.int
    SHARED_BLKS_WRITTEN_FIELD_NUMBER: builtins.int
    LOCAL_BLKS_HIT_FIELD_NUMBER: builtins.int
    LOCAL_BLKS_READ_FIELD_NUMBER: builtins.int
    LOCAL_BLKS_DIRTIED_FIELD_NUMBER: builtins.int
    LOCAL_BLKS_WRITTEN_FIELD_NUMBER: builtins.int
    TEMP_BLKS_READ_FIELD_NUMBER: builtins.int
    TEMP_BLKS_WRITTEN_FIELD_NUMBER: builtins.int
    BLK_READ_TIME_FIELD_NUMBER: builtins.int
    BLK_WRITE_TIME_FIELD_NUMBER: builtins.int
    TEMP_BLK_READ_TIME_FIELD_NUMBER: builtins.int
    TEMP_BLK_WRITE_TIME_FIELD_NUMBER: builtins.int
    WAL_RECORDS_FIELD_NUMBER: builtins.int
    WAL_FPI_FIELD_NUMBER: builtins.int
    WAL_BYTES_FIELD_NUMBER: builtins.int
    JIT_FUNCTIONS_FIELD_NUMBER: builtins.int
    JIT_GENERATION_TIME_FIELD_NUMBER: builtins.int
    JIT_INLINING_COUNT_FIELD_NUMBER: builtins.int
    JIT_INLINING_TIME_FIELD_NUMBER: builtins.int
    JIT_OPTIMIZATION_COUNT_FIELD_NUMBER: builtins.int
    JIT_OPTIMIZATION_TIME_FIELD_NUMBER: builtins.int
    JIT_EMISSION_COUNT_FIELD_NUMBER: builtins.int
    JIT_EMISSION_TIME_FIELD_NUMBER: builtins.int
    STARTUP_COST_FIELD_NUMBER: builtins.int
    TOTAL_COST_FIELD_NUMBER: builtins.int
    PLAN_ROWS_FIELD_NUMBER: builtins.int
    PLAN_WIDTH_FIELD_NUMBER: builtins.int
    READS_FIELD_NUMBER: builtins.int
    WRITES_FIELD_NUMBER: builtins.int
    USER_TIME_FIELD_NUMBER: builtins.int
    SYSTEM_TIME_FIELD_NUMBER: builtins.int
    query: builtins.str
    """Statement text."""
    normalized_plan: builtins.str
    """Normalized query plan."""
    example_plan: builtins.str
    """Example of a query execution plan (without normalization)."""
    plans: builtins.int
    """Number of times that a query was planned.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning](https://www.postgresql.org/docs/current/pgstatstatements.html#id-1.11.7.41.9) parameter is enabled.
    """
    total_plan_time: builtins.float
    """Total time taken to plan a query, in milliseconds.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning] parameter is enabled.
    """
    min_plan_time: builtins.float
    """Minimum time taken to plan a query, in milliseconds.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning] parameter is enabled.
    """
    max_plan_time: builtins.float
    """Maximum time taken to plan a query, in milliseconds.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning] parameter is enabled.
    """
    mean_plan_time: builtins.float
    """Average time taken to plan a query, in milliseconds.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning] parameter is enabled.
    """
    stddev_plan_time: builtins.float
    """Population standard deviation of the time taken to plan a query, in milliseconds.

    The parameter returns a non-zero value if the [pg_stat_statements.track_planning] parameter is enabled.
    """
    calls: builtins.int
    """Number of times that a query was executed."""
    total_time: builtins.float
    """Total time taken to execute a query, in milliseconds.
    total_exec_time
    """
    min_time: builtins.float
    """Minimum time taken to execute a query, in milliseconds.
    min_exec_time
    """
    max_time: builtins.float
    """Maximum time taken to execute a query, in milliseconds.
    max_exec_time
    """
    mean_time: builtins.float
    """Average time taken to execute a query, in milliseconds.
    mean_exec_time
    """
    stddev_time: builtins.float
    """Population standard deviation of the time taken to execute a query, in milliseconds.
    stddev_exec_time
    """
    rows: builtins.int
    """Number of retrieved or affected rows."""
    shared_blks_hit: builtins.int
    """Number of shared blocks that are hit from cache."""
    shared_blks_read: builtins.int
    """Number of read shared blocks."""
    shared_blks_dirtied: builtins.int
    """Number of 'dirtied' shared blocks."""
    shared_blks_written: builtins.int
    """Number of written shared blocks."""
    local_blks_hit: builtins.int
    """Number of local blocks that are hit from cache."""
    local_blks_read: builtins.int
    """Number of read local blocks."""
    local_blks_dirtied: builtins.int
    """Number of 'dirtied' local blocks."""
    local_blks_written: builtins.int
    """Number of written local blocks."""
    temp_blks_read: builtins.int
    """Number of read temporary blocks."""
    temp_blks_written: builtins.int
    """Number of written temporary blocks."""
    blk_read_time: builtins.float
    """Time taken to read data blocks, in milliseconds.

    The parameter returns a non-zero value if the [track_io_timing](https://www.postgresql.org/docs/current/runtime-config-statistics.html#GUC-TRACK-IO-TIMING) parameter is enabled.
    """
    blk_write_time: builtins.float
    """Time taken to record data blocks, in milliseconds.

    The parameter returns a non-zero value if the [track_io_timing] parameter is enabled.
    """
    temp_blk_read_time: builtins.float
    """Time taken to read temporary data blocks, in milliseconds.

    The parameter returns a non-zero value if the [track_io_timing] parameter is enabled.
    """
    temp_blk_write_time: builtins.float
    """Time taken to record temporary data blocks, in milliseconds.

    The parameter returns a non-zero value if the [track_io_timing] parameter is enabled.
    """
    wal_records: builtins.int
    """Number of WAL records generated during a given period."""
    wal_fpi: builtins.int
    """Number of WAL full page images generated during a given period."""
    wal_bytes: builtins.int
    """Number of WAL logs generated during a given period, in bytes."""
    jit_functions: builtins.int
    """Number of JIT-compiled functions."""
    jit_generation_time: builtins.float
    """Time taken to generate JIT code, in milliseconds."""
    jit_inlining_count: builtins.int
    """Number of times that functions have been inlined."""
    jit_inlining_time: builtins.float
    """Time taken to inline functions, in milliseconds."""
    jit_optimization_count: builtins.int
    """Number of times that a query was optimized."""
    jit_optimization_time: builtins.float
    """Time taken to optimize a query, in milliseconds."""
    jit_emission_count: builtins.int
    """Number of times that code was emitted."""
    jit_emission_time: builtins.float
    """Time taken to emit code."""
    startup_cost: builtins.int
    """Cost of receiving a response to a query before the first row of the response is issued."""
    total_cost: builtins.int
    """Cost of receiving a response to a query when all the rows of the response are issued."""
    plan_rows: builtins.int
    """Expected number of rows that a given plan node should issue."""
    plan_width: builtins.int
    """Expected average size of rows that a given plan node should issue."""
    reads: builtins.int
    """Number of bytes that the filesystem layer has read."""
    writes: builtins.int
    """Number of bytes that the filesystem layer has written."""
    user_time: builtins.float
    """User CPU time used."""
    system_time: builtins.float
    """System CPU time used."""
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of collecting statistics on planning and execution of queries."""

    def __init__(
        self,
        *,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        query: builtins.str = ...,
        normalized_plan: builtins.str = ...,
        example_plan: builtins.str = ...,
        plans: builtins.int = ...,
        total_plan_time: builtins.float = ...,
        min_plan_time: builtins.float = ...,
        max_plan_time: builtins.float = ...,
        mean_plan_time: builtins.float = ...,
        stddev_plan_time: builtins.float = ...,
        calls: builtins.int = ...,
        total_time: builtins.float = ...,
        min_time: builtins.float = ...,
        max_time: builtins.float = ...,
        mean_time: builtins.float = ...,
        stddev_time: builtins.float = ...,
        rows: builtins.int = ...,
        shared_blks_hit: builtins.int = ...,
        shared_blks_read: builtins.int = ...,
        shared_blks_dirtied: builtins.int = ...,
        shared_blks_written: builtins.int = ...,
        local_blks_hit: builtins.int = ...,
        local_blks_read: builtins.int = ...,
        local_blks_dirtied: builtins.int = ...,
        local_blks_written: builtins.int = ...,
        temp_blks_read: builtins.int = ...,
        temp_blks_written: builtins.int = ...,
        blk_read_time: builtins.float = ...,
        blk_write_time: builtins.float = ...,
        temp_blk_read_time: builtins.float = ...,
        temp_blk_write_time: builtins.float = ...,
        wal_records: builtins.int = ...,
        wal_fpi: builtins.int = ...,
        wal_bytes: builtins.int = ...,
        jit_functions: builtins.int = ...,
        jit_generation_time: builtins.float = ...,
        jit_inlining_count: builtins.int = ...,
        jit_inlining_time: builtins.float = ...,
        jit_optimization_count: builtins.int = ...,
        jit_optimization_time: builtins.float = ...,
        jit_emission_count: builtins.int = ...,
        jit_emission_time: builtins.float = ...,
        startup_cost: builtins.int = ...,
        total_cost: builtins.int = ...,
        plan_rows: builtins.int = ...,
        plan_width: builtins.int = ...,
        reads: builtins.int = ...,
        writes: builtins.int = ...,
        user_time: builtins.float = ...,
        system_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blk_read_time", b"blk_read_time", "blk_write_time", b"blk_write_time", "calls", b"calls", "example_plan", b"example_plan", "jit_emission_count", b"jit_emission_count", "jit_emission_time", b"jit_emission_time", "jit_functions", b"jit_functions", "jit_generation_time", b"jit_generation_time", "jit_inlining_count", b"jit_inlining_count", "jit_inlining_time", b"jit_inlining_time", "jit_optimization_count", b"jit_optimization_count", "jit_optimization_time", b"jit_optimization_time", "local_blks_dirtied", b"local_blks_dirtied", "local_blks_hit", b"local_blks_hit", "local_blks_read", b"local_blks_read", "local_blks_written", b"local_blks_written", "max_plan_time", b"max_plan_time", "max_time", b"max_time", "mean_plan_time", b"mean_plan_time", "mean_time", b"mean_time", "min_plan_time", b"min_plan_time", "min_time", b"min_time", "normalized_plan", b"normalized_plan", "plan_rows", b"plan_rows", "plan_width", b"plan_width", "plans", b"plans", "query", b"query", "reads", b"reads", "rows", b"rows", "shared_blks_dirtied", b"shared_blks_dirtied", "shared_blks_hit", b"shared_blks_hit", "shared_blks_read", b"shared_blks_read", "shared_blks_written", b"shared_blks_written", "startup_cost", b"startup_cost", "stddev_plan_time", b"stddev_plan_time", "stddev_time", b"stddev_time", "system_time", b"system_time", "temp_blk_read_time", b"temp_blk_read_time", "temp_blk_write_time", b"temp_blk_write_time", "temp_blks_read", b"temp_blks_read", "temp_blks_written", b"temp_blks_written", "time", b"time", "total_cost", b"total_cost", "total_plan_time", b"total_plan_time", "total_time", b"total_time", "user_time", b"user_time", "wal_bytes", b"wal_bytes", "wal_fpi", b"wal_fpi", "wal_records", b"wal_records", "writes", b"writes"]) -> None: ...

global___QueryStats = QueryStats

@typing.final
class QueryStatement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    STATS_FIELD_NUMBER: builtins.int
    @property
    def key(self) -> global___PrimaryKey:
        """Primary keys in tables with the statistics on planning and execution of queries."""

    @property
    def stats(self) -> global___QueryStats:
        """Statistics on planning and execution of queries."""

    def __init__(
        self,
        *,
        key: global___PrimaryKey | None = ...,
        stats: global___QueryStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key", "stats", b"stats"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "stats", b"stats"]) -> None: ...

global___QueryStatement = QueryStatement



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Subtitle(google.protobuf.message.Message):
    """Entity representing a subtitle track that can be associated with a video.
    Subtitles provide text versions of the audio content, enabling accessibility
    and multilingual support for video content.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SubtitleStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SubtitleStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Subtitle._SubtitleStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUBTITLE_STATUS_UNSPECIFIED: Subtitle._SubtitleStatus.ValueType  # 0
        """The subtitle status is not specified."""
        WAIT_UPLOADING: Subtitle._SubtitleStatus.ValueType  # 1
        """The subtitle file upload is in progress, waiting for all bytes to be received."""
        UPLOADED: Subtitle._SubtitleStatus.ValueType  # 2
        """The subtitle file has been fully uploaded and is ready for use."""

    class SubtitleStatus(_SubtitleStatus, metaclass=_SubtitleStatusEnumTypeWrapper):
        """Current processing status of the subtitle."""

    SUBTITLE_STATUS_UNSPECIFIED: Subtitle.SubtitleStatus.ValueType  # 0
    """The subtitle status is not specified."""
    WAIT_UPLOADING: Subtitle.SubtitleStatus.ValueType  # 1
    """The subtitle file upload is in progress, waiting for all bytes to be received."""
    UPLOADED: Subtitle.SubtitleStatus.ValueType  # 2
    """The subtitle file has been fully uploaded and is ready for use."""

    class _SubtitleSourceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SubtitleSourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Subtitle._SubtitleSourceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUBTITLE_SOURCE_TYPE_UNSPECIFIED: Subtitle._SubtitleSourceType.ValueType  # 0
        """The subtitle source type is not specified."""
        MANUAL: Subtitle._SubtitleSourceType.ValueType  # 1
        """The subtitle was manually created and uploaded by a user."""
        GENERATED: Subtitle._SubtitleSourceType.ValueType  # 2
        """The subtitle was automatically generated through speech recognition."""

    class SubtitleSourceType(_SubtitleSourceType, metaclass=_SubtitleSourceTypeEnumTypeWrapper):
        """Source type representing how the subtitle was created or obtained."""

    SUBTITLE_SOURCE_TYPE_UNSPECIFIED: Subtitle.SubtitleSourceType.ValueType  # 0
    """The subtitle source type is not specified."""
    MANUAL: Subtitle.SubtitleSourceType.ValueType  # 1
    """The subtitle was manually created and uploaded by a user."""
    GENERATED: Subtitle.SubtitleSourceType.ValueType  # 2
    """The subtitle was automatically generated through speech recognition."""

    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the subtitle track."""
    language: builtins.str
    """Language of the subtitle content according to ISO 639-2/T."""
    label: builtins.str
    """Display label for the subtitle track shown in the video player's subtitle selection menu."""
    status: global___Subtitle.SubtitleStatus.ValueType
    """Current processing status of the subtitle."""
    source_type: global___Subtitle.SubtitleSourceType.ValueType
    """Indicates how the subtitle was created or obtained."""
    filename: builtins.str
    """Original filename of the subtitle file."""
    video_id: builtins.str
    """Identifier of the video this subtitle belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the subtitle was initially created in the system."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the subtitle or its metadata."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        language: builtins.str = ...,
        label: builtins.str = ...,
        status: global___Subtitle.SubtitleStatus.ValueType = ...,
        source_type: global___Subtitle.SubtitleSourceType.ValueType = ...,
        filename: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        video_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "parent_id", b"parent_id", "updated_at", b"updated_at", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "filename", b"filename", "id", b"id", "label", b"label", "language", b"language", "parent_id", b"parent_id", "source_type", b"source_type", "status", b"status", "updated_at", b"updated_at", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["video_id"] | None: ...

global___Subtitle = Subtitle



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/symmetric_key_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/symmetric_key_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1 import symmetric_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/kms/v1/symmetric_key_service.proto\x12\x13yandex.cloud.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/kms/v1/symmetric_key.proto\"\xca\x03\n\x19\x43reateSymmetricKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.kms.v1.CreateSymmetricKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12H\n\x11\x64\x65\x66\x61ult_algorithm\x18\x05 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithmB\x04\xe8\xc7\x31\x01\x12\x32\n\x0frotation_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x1a\x43reateSymmetricKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x1a\n\x12primary_version_id\x18\x02 \x01(\t\"6\n\x16GetSymmetricKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"y\n\x18ListSymmetricKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"e\n\x19ListSymmetricKeysResponse\x12/\n\x04keys\x18\x01 \x03(\x0b\x32!.yandex.cloud.kms.v1.SymmetricKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"}\n\x1fListSymmetricKeyVersionsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"{\n ListSymmetricKeyVersionsResponse\x12>\n\x0ckey_versions\x18\x01 \x03(\x0b\x32(.yandex.cloud.kms.v1.SymmetricKeyVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x04\n\x19UpdateSymmetricKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x38\n\x06status\x18\x05 \x01(\x0e\x32(.yandex.cloud.kms.v1.SymmetricKey.Status\x12\x87\x01\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.kms.v1.UpdateSymmetricKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x42\n\x11\x64\x65\x66\x61ult_algorithm\x18\x07 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12\x32\n\x0frotation_period\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x1aUpdateSymmetricKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"9\n\x19\x44\x65leteSymmetricKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\",\n\x1a\x44\x65leteSymmetricKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"f\n$SetPrimarySymmetricKeyVersionRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"K\n%SetPrimarySymmetricKeyVersionMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"9\n\x19RotateSymmetricKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"L\n\x1aRotateSymmetricKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x1e\n\x16new_primary_version_id\x18\x02 \x01(\t\"\xa2\x01\n-ScheduleSymmetricKeyVersionDestructionRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x31\n\x0epending_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x84\x01\n.ScheduleSymmetricKeyVersionDestructionMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12.\n\ndestroy_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n+CancelSymmetricKeyVersionDestructionRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"R\n,CancelSymmetricKeyVersionDestructionMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"\x7f\n!ListSymmetricKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListSymmetricKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf6\x14\n\x13SymmetricKeyService\x12\xa2\x01\n\x06\x43reate\x12..yandex.cloud.kms.v1.CreateSymmetricKeyRequest\x1a!.yandex.cloud.operation.Operation\"E\xb2\xd2**\n\x1a\x43reateSymmetricKeyMetadata\x12\x0cSymmetricKey\x82\xd3\xe4\x93\x02\x11\"\x0c/kms/v1/keys:\x01*\x12t\n\x03Get\x12+.yandex.cloud.kms.v1.GetSymmetricKeyRequest\x1a!.yandex.cloud.kms.v1.SymmetricKey\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/kms/v1/keys/{key_id}\x12{\n\x04List\x12-.yandex.cloud.kms.v1.ListSymmetricKeysRequest\x1a..yandex.cloud.kms.v1.ListSymmetricKeysResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/kms/v1/keys\x12\xa3\x01\n\x0cListVersions\x12\x34.yandex.cloud.kms.v1.ListSymmetricKeyVersionsRequest\x1a\x35.yandex.cloud.kms.v1.ListSymmetricKeyVersionsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/kms/v1/keys/{key_id}/versions\x12\xab\x01\n\x06Update\x12..yandex.cloud.kms.v1.UpdateSymmetricKeyRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2**\n\x1aUpdateSymmetricKeyMetadata\x12\x0cSymmetricKey\x82\xd3\xe4\x93\x02\x1a\x32\x15/kms/v1/keys/{key_id}:\x01*\x12\xa8\x01\n\x06\x44\x65lete\x12..yandex.cloud.kms.v1.DeleteSymmetricKeyRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2**\n\x1a\x44\x65leteSymmetricKeyMetadata\x12\x0cSymmetricKey\x82\xd3\xe4\x93\x02\x17*\x15/kms/v1/keys/{key_id}\x12\xde\x01\n\x11SetPrimaryVersion\x12\x39.yandex.cloud.kms.v1.SetPrimarySymmetricKeyVersionRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*5\n%SetPrimarySymmetricKeyVersionMetadata\x12\x0cSymmetricKey\x82\xd3\xe4\x93\x02,\"\'/kms/v1/keys/{key_id}:setPrimaryVersion:\x01*\x12\x8a\x02\n\x1aScheduleVersionDestruction\x12\x42.yandex.cloud.kms.v1.ScheduleSymmetricKeyVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*E\n.ScheduleSymmetricKeyVersionDestructionMetadata\x12\x13SymmetricKeyVersion\x82\xd3\xe4\x93\x02\x35\"0/kms/v1/keys/{key_id}:scheduleVersionDestruction:\x01*\x12\x82\x02\n\x18\x43\x61ncelVersionDestruction\x12@.yandex.cloud.kms.v1.CancelSymmetricKeyVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*C\n,CancelSymmetricKeyVersionDestructionMetadata\x12\x13SymmetricKeyVersion\x82\xd3\xe4\x93\x02\x33\"./kms/v1/keys/{key_id}:cancelVersionDestruction:\x01*\x12\xaf\x01\n\x06Rotate\x12..yandex.cloud.kms.v1.RotateSymmetricKeyRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2**\n\x1aRotateSymmetricKeyMetadata\x12\x0cSymmetricKey\x82\xd3\xe4\x93\x02\x1e\"\x1c/kms/v1/keys/{key_id}:rotate\x12\xab\x01\n\x0eListOperations\x12\x36.yandex.cloud.kms.v1.ListSymmetricKeyOperationsRequest\x1a\x37.yandex.cloud.kms.v1.ListSymmetricKeyOperationsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /kms/v1/keys/{key_id}/operations\x12\xac\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/kms/v1/keys/{resource_id}:listAccessBindings\x12\xdb\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31\",/kms/v1/keys/{resource_id}:setAccessBindings:\x01*\x12\xe7\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34\"//kms/v1/keys/{resource_id}:updateAccessBindings:\x01*BV\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.symmetric_key_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms'
  _globals['_CREATESYMMETRICKEYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['default_algorithm']._loaded_options = None
  _globals['_CREATESYMMETRICKEYREQUEST'].fields_by_name['default_algorithm']._serialized_options = b'\350\3071\001'
  _globals['_GETSYMMETRICKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_GETSYMMETRICKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSYMMETRICKEYSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATESYMMETRICKEYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATESYMMETRICKEYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_DELETESYMMETRICKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_DELETESYMMETRICKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST'].fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ROTATESYMMETRICKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_ROTATESYMMETRICKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST'].fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateSymmetricKeyMetadata\022\014SymmetricKey\202\323\344\223\002\021\"\014/kms/v1/keys:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\027\022\025/kms/v1/keys/{key_id}'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\016\022\014/kms/v1/keys'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListVersions']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002 \022\036/kms/v1/keys/{key_id}/versions'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateSymmetricKeyMetadata\022\014SymmetricKey\202\323\344\223\002\0322\025/kms/v1/keys/{key_id}:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322**\n\032DeleteSymmetricKeyMetadata\022\014SymmetricKey\202\323\344\223\002\027*\025/kms/v1/keys/{key_id}'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['SetPrimaryVersion']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['SetPrimaryVersion']._serialized_options = b'\262\322*5\n%SetPrimarySymmetricKeyVersionMetadata\022\014SymmetricKey\202\323\344\223\002,\"\'/kms/v1/keys/{key_id}:setPrimaryVersion:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ScheduleVersionDestruction']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ScheduleVersionDestruction']._serialized_options = b'\262\322*E\n.ScheduleSymmetricKeyVersionDestructionMetadata\022\023SymmetricKeyVersion\202\323\344\223\0025\"0/kms/v1/keys/{key_id}:scheduleVersionDestruction:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['CancelVersionDestruction']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['CancelVersionDestruction']._serialized_options = b'\262\322*C\n,CancelSymmetricKeyVersionDestructionMetadata\022\023SymmetricKeyVersion\202\323\344\223\0023\"./kms/v1/keys/{key_id}:cancelVersionDestruction:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Rotate']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['Rotate']._serialized_options = b'\262\322**\n\032RotateSymmetricKeyMetadata\022\014SymmetricKey\202\323\344\223\002\036\"\034/kms/v1/keys/{key_id}:rotate'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002\"\022 /kms/v1/keys/{key_id}/operations'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002/\022-/kms/v1/keys/{resource_id}:listAccessBindings'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0021\",/kms/v1/keys/{resource_id}:setAccessBindings:\001*'
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_SYMMETRICKEYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0024\"//kms/v1/keys/{resource_id}:updateAccessBindings:\001*'
  _globals['_CREATESYMMETRICKEYREQUEST']._serialized_start=382
  _globals['_CREATESYMMETRICKEYREQUEST']._serialized_end=840
  _globals['_CREATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_start=795
  _globals['_CREATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_end=840
  _globals['_CREATESYMMETRICKEYMETADATA']._serialized_start=842
  _globals['_CREATESYMMETRICKEYMETADATA']._serialized_end=914
  _globals['_GETSYMMETRICKEYREQUEST']._serialized_start=916
  _globals['_GETSYMMETRICKEYREQUEST']._serialized_end=970
  _globals['_LISTSYMMETRICKEYSREQUEST']._serialized_start=972
  _globals['_LISTSYMMETRICKEYSREQUEST']._serialized_end=1093
  _globals['_LISTSYMMETRICKEYSRESPONSE']._serialized_start=1095
  _globals['_LISTSYMMETRICKEYSRESPONSE']._serialized_end=1196
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST']._serialized_start=1198
  _globals['_LISTSYMMETRICKEYVERSIONSREQUEST']._serialized_end=1323
  _globals['_LISTSYMMETRICKEYVERSIONSRESPONSE']._serialized_start=1325
  _globals['_LISTSYMMETRICKEYVERSIONSRESPONSE']._serialized_end=1448
  _globals['_UPDATESYMMETRICKEYREQUEST']._serialized_start=1451
  _globals['_UPDATESYMMETRICKEYREQUEST']._serialized_end=2013
  _globals['_UPDATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_start=795
  _globals['_UPDATESYMMETRICKEYREQUEST_LABELSENTRY']._serialized_end=840
  _globals['_UPDATESYMMETRICKEYMETADATA']._serialized_start=2015
  _globals['_UPDATESYMMETRICKEYMETADATA']._serialized_end=2059
  _globals['_DELETESYMMETRICKEYREQUEST']._serialized_start=2061
  _globals['_DELETESYMMETRICKEYREQUEST']._serialized_end=2118
  _globals['_DELETESYMMETRICKEYMETADATA']._serialized_start=2120
  _globals['_DELETESYMMETRICKEYMETADATA']._serialized_end=2164
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST']._serialized_start=2166
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONREQUEST']._serialized_end=2268
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONMETADATA']._serialized_start=2270
  _globals['_SETPRIMARYSYMMETRICKEYVERSIONMETADATA']._serialized_end=2345
  _globals['_ROTATESYMMETRICKEYREQUEST']._serialized_start=2347
  _globals['_ROTATESYMMETRICKEYREQUEST']._serialized_end=2404
  _globals['_ROTATESYMMETRICKEYMETADATA']._serialized_start=2406
  _globals['_ROTATESYMMETRICKEYMETADATA']._serialized_end=2482
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST']._serialized_start=2485
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONREQUEST']._serialized_end=2647
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONMETADATA']._serialized_start=2650
  _globals['_SCHEDULESYMMETRICKEYVERSIONDESTRUCTIONMETADATA']._serialized_end=2782
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST']._serialized_start=2784
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONREQUEST']._serialized_end=2893
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONMETADATA']._serialized_start=2895
  _globals['_CANCELSYMMETRICKEYVERSIONDESTRUCTIONMETADATA']._serialized_end=2977
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST']._serialized_start=2979
  _globals['_LISTSYMMETRICKEYOPERATIONSREQUEST']._serialized_end=3106
  _globals['_LISTSYMMETRICKEYOPERATIONSRESPONSE']._serialized_start=3108
  _globals['_LISTSYMMETRICKEYOPERATIONSRESPONSE']._serialized_end=3224
  _globals['_SYMMETRICKEYSERVICE']._serialized_start=3227
  _globals['_SYMMETRICKEYSERVICE']._serialized_end=5905
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.ytsaurus.v1.cluster_pb2
import yandex.cloud.ytsaurus.v1.cluster_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ClusterServiceStub:
    """A set of methods for managing Cluster resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified cluster."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of clusters in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a cluster in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified cluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified cluster."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified cluster."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified cluster."""

class ClusterServiceAsyncStub:
    """A set of methods for managing Cluster resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified cluster."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of clusters in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a cluster in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified cluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified cluster."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified cluster."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ytsaurus.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified cluster."""

class ClusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Cluster resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.GetClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster, collections.abc.Awaitable[yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster]]:
        """Returns the specified cluster."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersResponse, collections.abc.Awaitable[yandex.cloud.ytsaurus.v1.cluster_service_pb2.ListClustersResponse]]:
        """Retrieves the list of clusters in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.CreateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a cluster in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.UpdateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified cluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.DeleteClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified cluster."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.StartClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified cluster."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.ytsaurus.v1.cluster_service_pb2.StopClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified cluster."""

def add_ClusterServiceServicer_to_server(servicer: ClusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/batch_inference/v1/batch_inference_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/batch_inference/v1/batch_inference_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ai.batch_inference.v1 import batch_inference_task_pb2 as yandex_dot_cloud_dot_ai_dot_batch__inference_dot_v1_dot_batch__inference__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/ai/batch_inference/v1/batch_inference_service.proto\x12\"yandex.cloud.ai.batch_inference.v1\x1a\x1dyandex/cloud/validation.proto\x1a=yandex/cloud/ai/batch_inference/v1/batch_inference_task.proto\"\xaf\x01\n\x16\x42\x61tchInferenceMetadata\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12R\n\x0btask_status\x18\x02 \x01(\x0e\x32=.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.Status\x12\x19\n\x11\x63ompleted_batches\x18\x03 \x01(\x03\x12\x15\n\rtotal_batches\x18\x04 \x01(\x03\"^\n\x16\x42\x61tchInferenceResponse\x12\x44\n\x04task\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask\"6\n\x1d\x44\x65scribeBatchInferenceRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"f\n\x1e\x44\x65scribeBatchInferenceResponse\x12\x44\n\x04task\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask\"\xab\x01\n\x1aListBatchInferencesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12M\n\x06status\x18\x04 \x01(\x0e\x32=.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.Status\"}\n\x1bListBatchInferencesResponse\x12\x45\n\x05tasks\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x1b\x43\x61ncelBatchInferenceRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x1c\x43\x61ncelBatchInferenceResponse\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"4\n\x1b\x44\x65leteBatchInferenceRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x1c\x44\x65leteBatchInferenceResponse\x12\x0f\n\x07task_id\x18\x01 \x01(\t2\xd1\x04\n\x15\x42\x61tchInferenceService\x12\x91\x01\n\x08\x44\x65scribe\x12\x41.yandex.cloud.ai.batch_inference.v1.DescribeBatchInferenceRequest\x1a\x42.yandex.cloud.ai.batch_inference.v1.DescribeBatchInferenceResponse\x12\x87\x01\n\x04List\x12>.yandex.cloud.ai.batch_inference.v1.ListBatchInferencesRequest\x1a?.yandex.cloud.ai.batch_inference.v1.ListBatchInferencesResponse\x12\x8b\x01\n\x06\x43\x61ncel\x12?.yandex.cloud.ai.batch_inference.v1.CancelBatchInferenceRequest\x1a@.yandex.cloud.ai.batch_inference.v1.CancelBatchInferenceResponse\x12\x8b\x01\n\x06\x44\x65lete\x12?.yandex.cloud.ai.batch_inference.v1.DeleteBatchInferenceRequest\x1a@.yandex.cloud.ai.batch_inference.v1.DeleteBatchInferenceResponseBu\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomo'
  _globals['_DESCRIBEBATCHINFERENCEREQUEST'].fields_by_name['task_id']._loaded_options = None
  _globals['_DESCRIBEBATCHINFERENCEREQUEST'].fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBATCHINFERENCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBATCHINFERENCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CANCELBATCHINFERENCEREQUEST'].fields_by_name['task_id']._loaded_options = None
  _globals['_CANCELBATCHINFERENCEREQUEST'].fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEBATCHINFERENCEREQUEST'].fields_by_name['task_id']._loaded_options = None
  _globals['_DELETEBATCHINFERENCEREQUEST'].fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _globals['_BATCHINFERENCEMETADATA']._serialized_start=199
  _globals['_BATCHINFERENCEMETADATA']._serialized_end=374
  _globals['_BATCHINFERENCERESPONSE']._serialized_start=376
  _globals['_BATCHINFERENCERESPONSE']._serialized_end=470
  _globals['_DESCRIBEBATCHINFERENCEREQUEST']._serialized_start=472
  _globals['_DESCRIBEBATCHINFERENCEREQUEST']._serialized_end=526
  _globals['_DESCRIBEBATCHINFERENCERESPONSE']._serialized_start=528
  _globals['_DESCRIBEBATCHINFERENCERESPONSE']._serialized_end=630
  _globals['_LISTBATCHINFERENCESREQUEST']._serialized_start=633
  _globals['_LISTBATCHINFERENCESREQUEST']._serialized_end=804
  _globals['_LISTBATCHINFERENCESRESPONSE']._serialized_start=806
  _globals['_LISTBATCHINFERENCESRESPONSE']._serialized_end=931
  _globals['_CANCELBATCHINFERENCEREQUEST']._serialized_start=933
  _globals['_CANCELBATCHINFERENCEREQUEST']._serialized_end=985
  _globals['_CANCELBATCHINFERENCERESPONSE']._serialized_start=987
  _globals['_CANCELBATCHINFERENCERESPONSE']._serialized_end=1034
  _globals['_DELETEBATCHINFERENCEREQUEST']._serialized_start=1036
  _globals['_DELETEBATCHINFERENCEREQUEST']._serialized_end=1088
  _globals['_DELETEBATCHINFERENCERESPONSE']._serialized_start=1090
  _globals['_DELETEBATCHINFERENCERESPONSE']._serialized_end=1137
  _globals['_BATCHINFERENCESERVICE']._serialized_start=1140
  _globals['_BATCHINFERENCESERVICE']._serialized_end=1733
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.test.details_pb2
import yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2
import yandex.cloud.loadtesting.api.v1.test.summary_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Test(google.protobuf.message.Message):
    """Load Test.

    In context of the service, Test represents a single testing task/job.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the test. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the test belongs to."""
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2.SingleAgentConfiguration]:
        """Configuration of the test.

        A test can have multiple configurations if it can be
        executed on multiple agents simultaneously. For more information, see
        [Load testing using multiple agents](/docs/load-testing/tutorials/loadtesting-multiply).
        """

    @property
    def details(self) -> yandex.cloud.loadtesting.api.v1.test.details_pb2.Details:
        """Test meta information. Name, description, etc."""

    @property
    def summary(self) -> yandex.cloud.loadtesting.api.v1.test.summary_pb2.Summary:
        """Test execution information."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        configurations: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2.SingleAgentConfiguration] | None = ...,
        details: yandex.cloud.loadtesting.api.v1.test.details_pb2.Details | None = ...,
        summary: yandex.cloud.loadtesting.api.v1.test.summary_pb2.Summary | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["details", b"details", "summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["configurations", b"configurations", "details", b"details", "folder_id", b"folder_id", "id", b"id", "summary", b"summary"]) -> None: ...

global___Test = Test
